---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:decreto.legislativo:2000-12-28;443
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=20010220&codiceRedaz=000G0047&dataVigenza=20251104
dataGU: 20010220
codiceRedaz: 000G0047
dataVigenza: 20251104
---

# Disposizioni legislative in materia di documentazione amministrativa.(Testo B).

## DEFINIZIONI E AMBITO DI APPLICAZIONE

### Articolo 1

Definizioni 1.

### Art. 2. - (L) Oggetto

1. Le norme del presente testo unico disciplinano la formazione, il rilascio, la tenuta e la conservazione, la gestione, la trasmissione di atti e documenti da parte di organi della pubblica amministrazione: disciplinano altresi' la produzione di atti e documenti agli organi della pubblica amministrazione nonche' ai gestori di pubblici servizi, nei rapporti tra loro e in quelli con l'utenza e ai privati che vi consentono. (( PERIODO ABROGATO DAL D.LGS. 7 MARZO 2005, N. 82 ))

### Articolo 3 - (R) Soggetti

1. 2. 3. 4.

### Articolo 4 - (R) Impedimento alla sottoscrizione e alla dichiarazione

1. 2.

### Articolo 5 - (L) Rappresentanza legale

1. Se l'interessato e' soggetto alla potesta' dei genitori, a tutela, o a curatela, le dichiarazioni e i documenti previsti dal presente testo unico sono sottoscritti rispettivamente dal genitore esercente la potesta' dei genitori, dal tutore, o dall'interessato stesso con l'assistenza del curatore.

### DOCUMENTAZIONE AMMINISTRATIVA SEZIONE I DOCUMENTI AMMINISTRATIVI E ATTI PUBBLICI

#### Art. 6. - (L-R) Riproduzione di documenti

1. ((COMMA ABROGATO DAL D.LGS. 7 MARZO 2005, N. 82)).

2. ((COMMA ABROGATO DAL D.LGS. 7 MARZO 2005, N. 82)). 3. 4.

#### Articolo 7 - (L) Redazione e stesura di atti pubblici

1. I decreti, gli atti ricevuti dai notai, tutti gli altri atti pubblici, e le certificazioni sono redatti, anche promiscuamente, con qualunque mezzo idoneo.

2. Il testo degli atti pubblici comunque redatti non deve contenere lacune, aggiunte, abbreviazioni, correzioni, alterazioni o abrasioni. Sono ammesse abbreviazioni, acronimi, ed espressioni in lingua straniera di uso comune. Qualora risulti necessario apportare variazioni al testo, si provvede in modo che la precedente stesura resti leggibile.

### DOCUMENTAZIONE AMMINISTRATIVA SEZIONE II DOCUMENTO INFORMATICO

#### Articolo 8 - (R) Documento informatico

1. 2. 3. 4.

#### Articolo 9 - (R) Documenti informatici delle pubbliche amministrazioni

1. 2. 3. 4.

#### Art. 10.

(( ARTICOLO ABROGATO DAL D.LGS. 7 MARZO 2005, N. 82 ))

#### Articolo 11 - (R) Contratti stipulati con strumenti informatici o per via telematica

1. 2.

#### Articolo 12 - (R) Pagamenti informatici

1.

#### Articolo 13 - (R) Libri e scritture

1.

### DOCUMENTAZIONE AMMINISTRATIVA SEZIONE III TRASMISSIONE DI DOCUMENTI

#### Articolo 14

Trasmissione del documento informatico 1. 2. 3.

#### Articolo 15 - (L) Trasmissione dall'estero di atti agli uffici di stato civile

1. In materia di trasmissione di atti o copie di atti di stato civile o di dati concernenti la cittadinanza da parte delle rappresentanze diplomatiche e consolari italiane, si osservano le disposizioni speciali sulle funzioni e sui poteri consolari.

#### Articolo 16 - (R) Riservatezza dei dati personali contenuti nei documenti trasmessi

1. 2. 3.

#### Articolo 17 - (R) Segretezza della corrispondenza trasmessa per via telematica

1. 2.

### DOCUMENTAZIONE AMMINISTRATIVA SEZIONE IV COPIE AUTENTICHE, AUTENTICAZIONE DI SOTTOSCRIZIONI

#### Articolo 18 - (L-R) Copie autentiche

1. Le copie autentiche, totali o parziali, di atti e documenti possono essere ottenute con qualsiasi procedimento che dia garanzia della riproduzione fedele e duratura dell'atto o documento. Esse possono essere validamente prodotte in luogo degli originali.

2. L'autenticazione delle copie puo' essere fatta dal pubblico ufficiale dal quale e stato emesso o presso il quale e' depositato l'originale, o al quale deve essere prodotto il documento, nonche' da un notaio, cancelliere, segretario comunale, o altro funzionario incaricato dal sindaco. Essa consiste nell'attestazione di conformita' con l'originale scritta alla fine della copia, a cura del pubblico ufficiale autorizzato, il quale deve altresi' indicare la data e il luogo del rilascio, il numero dei fogli impiegati, il proprio nome e cognome, la qualifica rivestita nonche' apporre la propria firma per esteso ed il timbro dell'ufficio. Se la copia dell'atto o documento consta di piu' fogli il pubblico ufficiale appone la propria firma a margine di ciascun foglio intermedio. Per le copie di atti e documenti informatici si applicano le disposizioni contenute nell'articolo 20.

3. (R)

#### Articolo 19 - (R) Modalita' alternative all'autenticazione di copie

1.

#### Articolo 20 - (R) Copie di atti e documenti informatici

1. 2. 3. 4. 5.

#### Articolo 21 - (R) Autenticazione delle sottoscrizioni

1. 2.

### DOCUMENTAZIONE AMMINISTRATIVA SEZIONE V FIRMA DIGITALE

#### Articolo 22 - (R) Definizioni

1.

#### Articolo 23 - (R) Firma digitale

1. 2. 3. 4. 5. 6. 7.

#### Articolo 24 - (R) Firma digitale autenticata

1. 2. 3. 4. 5. 6.

#### Articolo 25

Firma di documenti informatici delle pubbliche amministrazioni 1. 2.

#### Articolo 26 - (R) Deposito della chiave privata

1. 2. 3.

#### Articolo 27 - (R) Certificazione delle chiavi

1. 2. 3. 4.

#### Articolo 28 - (R) Obblighi dell'utente e del certificatore

1. 2.

#### Articolo 29 - (R) Chiavi di cifratura della pubblica amministrazione

1. 2. 3. 4.

### DOCUMENTAZIONE AMMINISTRATIVA SEZIONE VI LEGALIZZAZIONE DI FIRME E DI FOTOGRAFIE

#### Articolo 30 - (L) Modalita' per la legalizzazione di firme

1. Nelle legalizzazioni devono essere indicati il nome e il cognome di colui la cui firma si legalizza. Il pubblico ufficiale legalizzante deve indicare la data e il luogo della legalizzazione, il proprio nome e cognome, la qualifica rivestita, nonche' apporre la propria firma per esteso ed il timbro dell'ufficio.

#### Articolo 31 - (L) Atti non soggetti a legalizzazione

1. Salvo quanto previsto negli articoli 32 e 33, non sono soggette a legalizzazione le firme apposte da pubblici funzionari o pubblici ufficiali su atti, certificati, copie ed estratti dai medesimi rilasciati. Il funzionario o pubblico ufficiale deve indicare la data e il luogo del rilascio, il proprio nome e cognome, la qualifica rivestita nonche' apporre la propria firma per esteso ed il timbro dell'ufficio.

#### Articolo 32

Legalizzazione di firme di capi di scuole parificate o legalmente riconosciute

1. Le firme dei capi delle scuole parificate o legalmente riconosciute sui diplomi originali o sui certificati di studio da prodursi ad uffici pubblici fuori della provincia in cui ha sede la scuola sono legalizzate dal provveditore agli studi.

#### Articolo 33 - (L) Legalizzazione di firme di atti da e per l'estero

1. Le firme sugli atti e documenti formati nello Stato e da valere all'estero davanti ad autorita' estere sono, ove da queste richiesto, legalizzate a cura dei competenti organi, centrali o periferici, del Ministero competente, o di altri organi e autorita' delegati dallo stesso.

2. Le firme sugli atti e documenti formati all'estero da autorita' estere e da valere nello Stato sono legalizzate dalle rappresentanze diplomatiche o consolari italiane all'estero. Le firme apposte su atti e documenti dai competenti organi delle rappresentanze diplomatiche o consolari italiane o dai funzionari da loro delegati non sono soggette a legalizzazione. Si osserva l'articolo 31

3. Agli atti e documenti indicati nel comma precedente, redatti in lingua straniera, deve essere allegata una traduzione in lingua italiana certificata conforme al testo straniero dalla competente rappresentanza diplomatica o consolare, ovvero da un traduttore ufficiale.

4. Le firme sugli atti e documenti formati nello Stato e da valere nello Stato, rilasciati da una rappresentanza diplomatica o consolare estera residente nello Stato sono legalizzate a cura delle prefetture.

5. Sono fatte salve le esenzioni dall'obbligo della legalizzazione e della traduzione stabilite da leggi o da accordi internazionali.

#### Articolo 34 - (L) Legalizzazione di fotografie

1. Le amministrazioni competenti per il rilascio di documenti personali sono tenute a legalizzare le prescritte fotografie presentate personalmente dall'interessato. Su richiesta di quest'ultimo le fotografie possono essere, altresi', legalizzate dal dipendente incaricato dal Sindaco.

2. La legalizzazione delle fotografie prescritte per il rilascio dei documenti personali non e' soggetta all'obbligo del pagamento dell'imposta di bollo.

### DOCUMENTAZIONE AMMINISTRATIVA SEZIONE VII DOCUMENTI DI RICONOSCIMENTI E DI IDENTITA'

#### Articolo 35 - (L-R) Documenti di identita' e di riconoscimento

1. (R)

2. (R)

3. Nei documenti d'identita' e di riconoscimento non e' necessaria l'indicazione o l'attestazione dello stato civile, salvo specifica istanza del richiedente.

#### Art. 36. - (L) Carta di identita' e documenti elettronici

1. ((COMMA ABROGATO DAL D.LGS 7 MARZO 2005, N. 82)).

2. ((COMMA ABROGATO DAL D.LGS 7 MARZO 2005, N. 82)).

3. ((COMMA ABROGATO DAL D.LGS 7 MARZO 2005, N. 82)).

4. ((COMMA ABROGATO DAL D.LGS 7 MARZO 2005, N. 82)).

5. ((COMMA ABROGATO DAL D.LGS 7 MARZO 2005, N. 82)).

6. ((COMMA ABROGATO DAL D.LGS 7 MARZO 2005, N. 82)).

7. La carta di identita', ancorche' su supporto cartaceo, puo' essere rinnovata a decorrere dal centottantesimo giorno precedente la scadenza.

### DOCUMENTAZIONE AMMINISTRATIVA SEZIONE VIII REGIME FISCALE

#### Articolo 37 - (L) Esenzioni fiscali

1. Le dichiarazioni sostitutive di cui agli articoli 46 e 47 sono esenti dall'imposta di bollo. 2 L'imposta di bollo non e' dovuta quando per le leggi vigenti sia esente da bollo l'atto sostituito ovvero quello nel quale e' apposta la firma da legalizzare.

### SEMPLIFICAZIONE DELLA DOCUMENTAZIONE AMMINISTRATIVA SEZIONE I ISTANZE E DICHIARAZIONI DA PRESENTARE ALLA PUBBLICA AMMINISTRAZIONE

#### Articolo 38 - (L-R) Modalita' di invio e sottoscrizione delle istanze

1. Tutte le istanze e le dichiarazioni da presentare alla pubblica amministrazione o ai gestori o esercenti di pubblici servizi possono essere inviate anche per fax e via telematica. 2.(R) 3. Le istanze e le dichiarazioni sostitutive di atto di notorieta' da produrre agli organi della amministrazione pubblica o ai gestori o esercenti di pubblici servizi sono sottoscritte dall'interessato in presenza del dipendente addetto ovvero sottoscritte e presentate unitamente a copia fotostatica non autenticata di un documento di identita' del sottoscrittore. La copia fotostatica del documento e' inserita nel fascicolo. Le istanze e la copia fotostatica del documento di identita' possono essere inviate per via telematica; nei procedimenti di aggiudicazione di contratti pubblici, detta facolta' e' consentita nei limiti stabiliti dal regolamento di cui all'articolo 15, comma 2 della legge 15 marzo 1997, n. 59.

#### Articolo 39 - (L) Domande, per la partecipazione a concorsi pubblici

1. La sottoscrizione delle domande per la partecipazione a selezioni per l'assunzione, a qualsiasi titolo, in tutte le pubbliche amministrazioni, nonche' ad esami per il conseguimento di abilitazioni, diplomi o titoli culturali non e soggetta ad autenticazione.

### SEMPLIFICAZIONE DELLA DOCUMENTAZIONE AMMINISTRATIVA SEZIONE II CERTIFICATI

#### Articolo 40 - (L) Certificazioni contestuali

1. Le certificazioni da rilasciarsi da uno stesso ufficio in ordine a stati, qualita' personali e fatti, concernenti la stessa persona, nell'ambito del medesimo procedimento, sono contenute in un unico documento.

#### Articolo 41 - (L) Validita' dei certificati

1. I certificati rilasciati dalle pubbliche amministrazioni attestanti stati, qualita' personali e fatti non soggetti a modificazioni hanno validita' illimitata. Le restanti certificazioni hanno validita' di sei mesi dalla data di rilascio se disposizioni di legge o regolamentari non prevedono una validita' superiore.

2. I certificati anagrafici, le certificazioni dello stato civile, gli estratti e le copie integrali degli atti di stato civile sono ammessi dalle pubbliche amministrazioni nonche' dai gestori o esercenti di pubblici servizi anche oltre i termini di validita' nel caso in cui l'interessato dichiari, in fondo al documento, che le informazioni contenute nel certificato stesso non hanno subito variazioni dalla data di rilascio. Il procedimento per il quale gli atti certificativi sono richiesti deve avere comunque corso, una volta acquisita la dichiarazione dell'interessato. Resta ferma la facolta' di verificare la veridicita' e la autenticita' delle attestazioni prodotte. In caso di falsa dichiarazione si applicano le disposizioni di cui all'articolo 76.

#### Articolo 42 - (R) Certificati di abilitazione

1.

### SEMPLIFICAZIONE DELLA DOCUMENTAZIONE AMMINISTRATIVA SEZIONE III ACQUISIZIONE DIRETTA DI DOCUMENTI

#### Articolo 43 - (L-R) Accertamenti d'ufficio

1.

2. Fermo restando il divieto di accesso a dati diversi da quelli di cui e' necessario acquisire la certezza o verificare l'esattezza, si considera operata per finalita' di rilevante interesse pubblico ai fini del decreto legislativo 11 maggio 1999, n. 135 la consultazione diretta, da parte di una pubblica amministrazione o di un gestore di pubblico servizio, degli archivi dell'amministrazione certificante effettuata, finalizzata all'accertamento d'ufficio di stati, qualita' e fatti ovvero al controllo sulle dichiarazioni sostitutive presentate dai cittadini. Per l'accesso diretto ai propri archivi l'amministrazione certificante rilascia all'amministrazione procedente apposita autorizzazione in cui vengono indicati i limiti e le condizioni di accesso volti ad assicurare la riservatezza dei dati personali ai sensi della normativa vigente. 3. 4. 5. 6.

#### Articolo 44 - (R) Acquisizione di estratti degli atti dello stato civile

1. 2.

### SEMPLIFICAZIONE DELLA DOCUMENTAZIONE AMMINISTRATIVA SEZIONE IV ESIBIZIONE DI DOCUMENTO

#### Articolo 45 - (L-R) Documentazione mediante esibizione

1. I dati relativi a cognome, nome, luogo e data di nascita, la cittadinanza, lo stato civile e la residenza attestati in documenti di identita' o di riconoscimento in corso di validita', possono essere comprovati mediante esibizione dei documenti medesimi. E' fatto divieto alle amministrazioni pubbliche ed ai gestori o esercenti di pubblici servizi, nel caso in cui all'atto della presentazione dell'istanza sia richiesta l'esibizione di un documento di identita' o di riconoscimento, di richiedere certificati attestanti stati o fatti contenuti nel documento esibito. E', comunque, fatta salva per le amministrazioni pubbliche ed i gestori e gli esercenti di pubblici sevizi la facolta' di verificare, nel corso del procedimento, la veridicita' dei dati contenuti nel documento di identita' o di riconoscimento. 2. 3.

### SEMPLIFICAZIONE DELLA DOCUMENTAZIONE AMMINISTRATIVA SEZIONE V NORME IN MATERIA DI DICHIARAZIONI SOSTITUTIVE

#### Articolo 46 - (R) Dichiarazioni sostitutive di certificazioni

1.

#### Articolo 47 - (R) Dichiarazioni sostitutive dell'atto di notorieta'

1. 2. 3. 4.

#### Articolo 48 - (R) Disposizioni generali in materia di dichiarazioni sostitutive

1. 2. 3.

#### Articolo 49 - (R) Limiti di utilizzo delle misure di semplificazione

1. 2.

### SISTEMA DI GESTIONE INFORMATICA DEI DOCUMENTI SEZIONE I DISPOSIZIONI SULLA GESTIONE INFORMATICA DEI DOCUMENTI

#### Articolo 50 - (R) Attuazione dei sistemi

1. 2. 3. 4. 5.

#### Art. 51. - R) Sviluppo dei sistemi informativi delle pubbliche amministrazioni

1. 2. 3.

#### Articolo 52 - (R) Il sistema di gestione informatica dei documenti

1.

#### Articolo 53 - (R) Registrazione di protocollo

1. 2. 3. 4. 5.

#### Articolo 54 - (R) Informazioni annullate o modificate

1. 2.

#### Articolo 55 - (R) Segnatura di protocollo

1. 2. 3. 4. 5.

#### Articolo 56 - (R) Operazioni ed informazioni minime del sistema di gestione informatica dei documenti

1.

#### Articolo 57 - (R) Numero di protocollo

1.

## SISTEMA DI GESTIONE INFORMATICA DEI DOCUMENTI SEZIONE SECONDA ACCESSO AI DOCUMENTI E ALLE INFORMAZIONI DEL SISTEMA

### Articolo 58 - (R) Funzioni di accesso ai documenti e alle informazioni del sistema

1. 2. 3.

### Articolo 59 - (R) Accesso esterno

1. 2. 3. 4.

### Articolo 60 - (R) Accesso effettuato dalle pubbliche amministrazioni

1. 2. 3.

## SISTEMA DI GESTIONE INFORMATICA DEI DOCUMENTI SEZIONE TERZA TENUTA E CONSERVAZIONE DEL SISTEMA DI GESTIONE DEI DOCUMENTI

### Articolo 61 - (R) Servizio per la gestione informatica dei documenti dei flussi documentali e degli archivi

1. 2. 3.

### Articolo 62 - (R) Procedure di salvataggio e conservazione delle informazioni del sistema

1. 2. 3. 4.

### Articolo 63 - (R) Registro di emergenza

1. 2. 3. 4. 5.

## SISTEMA DI GESTIONE INFORMATICA DEI DOCUMENTI SEZIONE QUARTA SISTEMA DI GESTIONE DEI FLUSSI DOCUMENTALI

### Art. 64. - R) Sistema di gestione dei flussi documentali

1. 2. 3. 4.

### Articolo 65 - (R) Requisiti del sistema per la gestione dei flussi documentali

1.

### Articolo 66 - (R) Specificazione delle informazioni previste dal sistema di gestione dei flussi documentali

1.

## SISTEMA DI GESTIONE INFORMATICA DEI DOCUMENTI SEZIONE QUINTA DISPOSIZIONI SUGLI ARCHIVI

### Articolo 67 - (R) Trasferimento dei documenti all'archivio di deposito

1. 2. 3.

### Articolo 68 - (R) Disposizioni per la conservazione degli archivi

1. 2. 3.

### Articolo 69 - (R) Archivi storici

1.

## SISTEMA DI GESTIONE INFORMATICA DEI DOCUMENTI SEZIONE SESTA ATTUAZIONE ED AGGIORNAMENTO DEI SISTEMI

### Articolo 70

Aggiornamenti del sistema 1.

## CONTROLLI

### Articolo 71 - (L-R) Modalita' dei controlli

1. 2. 3.

4. Qualora il controllo riguardi dichiarazioni sostitutive presentate ai privati che vi consentono di cui all'articolo 2. l'amministrazione competente per il rilascio della relativa certificazione, previa definizione di appositi accordi, e' tenuta a fornire, su richiesta del soggetto privato corredata dal consenso del dichiarante, conferma scritta, anche attraverso l'uso di strumenti informatici o telematici, della corrispondenza di quanto dichiarato con le risultanze dei dati da essa custoditi. (L)

### Art. 72. - R) Responsabilita' dei controlli

1. 2.

## SANZIONI

### Articolo 73 - (R) Assenza di responsabilita' della pubblica amministrazione

1.

### Articolo 74

Violazione dei doveri d'ufficio

1. Costituisce violazione dei doveri d'ufficio la mancata accettazione delle dichiarazioni sostitutive di certificazione o di atto di notorieta' rese a norma delle disposizioni del presente testo unico: 2.

### Articolo 75 - (R) Decadenza dai benefici

1.

### Articolo 76 - (L) Norme penali

1. Chiunque rilascia dichiarazioni mendaci, forma atti falsi o ne fa uso nei casi previsti dal presente testo unico e punito ai sensi del codice penale e delle leggi speciali in materia.

2. L'esibizione di un atto contenente dati non piu' rispondenti a verita' equivale ad uso di atto falso.

3. Le dichiarazioni sostitutive rese ai sensi degli articoli 46 e 47 e le dichiarazioni rese per conto delle persone indicate nell'articolo 4, comma 2, sono considerate come fatte a pubblico ufficiale.

4. Se i reati indicati nei commi 1, 2 e 3 sono commessi per ottenere la nomina ad un pubblico ufficio o l'autorizzazione all'esercizio di una professione o arte, il giudice, nei casi piu' gravi, puo' applicare l'interdizione temporanea dai pubblici uffici o dalla professione e arte.

## DISPOSIZIONI FINALI

### Articolo 77 - (L-R) Norme abrogate

1. Dalla data di entrata in vigore del presente testo unico sono abrogati: la legge 4 gennaio 1968 n. l5: l'articolo 2, comma 15, primo periodo della legge 24 dicembre 1993 n. 537; l'articolo 2 commi 3, 4, 7, 9 e 10 e l'articolo 3 commi 1, 4, 5, e 11 come sostituito dall'articolo 2, comma 10 della legge 16 giugno 1998, n. 191, della legge 15 maggio 1997 n. 127; l'articolo 2, comma 11 della citata legge 16 giugno 1998 n. 191; gli articoli 2 e 3 della legge 24 novembre 2000, n. 340; l'articolo 55, comma 3 della legge 21 novembre 2000, n. 342. (L) 2.

### Art. 78. - (L-R) Norme che rimangono in vigore

1. a) tutte le disposizioni legislative e regolamentari vigenti in materia di trasmissione delle dichiarazioni fiscali di cui al D.P.R. 22 luglio 1998, n. 399, al D.P.R. 14 ottobre 1999, n. 542, al D.P.R. 10 marzo 2000, n. 100, al decreto direttoriale 31 luglio 1998, al decreto direttoriale 29 marzo 2000, al D.M. 31 maggio 1999, n. l64, e le disposizioni di cui al decreto legislativo 31 marzo 1998, n. 109 concernenti la dichiarazione sostitutiva unica per la determinazione dell'indicatore della situazione economica equivalente dei soggetti che richiedono prestazioni sociali agevolate: b) il D.P.R. 26 ottobre 1972 n. 642 in materia di imposta di bollo: c) gli articoli 18 e 30 della legge 7 agosto 1990 n. 941: d) l'articolo 2, comma 15, secondo periodo della legge 24 dicembre 1993 n. 537: e) le disposizioni in materia di dati personali di cui alla legge 31 dicembre 1996, n. 675 e ai decreti legislativi adottati in attuazione delle leggi 31 dicembre 1996, n. 676 e 6 ottobre 1998, n. 344: f) fino alla loro sostituzione, i regolamenti ministeriali, le direttive e i decreti ministeriali a contenuto generale, nonche' le regole tecniche gia' emanate alla data di entrata in vigore del presente testo unico: e) tutte le disposizioni legislative in materia di conservazione di beni archivistici di cui al capo II del D.Lgs. 29 ottobre 1999, n. 490. 2. Per le forze di polizia, restano in vigore, con riferimento agli articoli 43, comma 4, 59 e 60, le particolari disposizioni di legge e di regolamento concernenti i trattamenti di dati personali da parte delle forze dell'ordine, ai sensi dell'articolo 4 legge 31 dicembre 1996, n. 675.

